@@ -8,7 +8,6 @@ from .parser import Parser
 
 class Carib(Parser):
     source = 'carib'
-    uncensored = True
 
     expr_title = "//div[@class='movie-info section']/div[@class='heading']/h1[@itemprop='name']/text()"
     expr_release = "//li[2]/span[@class='spec-content']/text()"
@@ -20,9 +19,15 @@ class Carib(Parser):
     expr_series = "//span[@class='spec-title'][contains(text(),'シリーズ')]/../span[@class='spec-content']/a/text()"
     expr_outline = "//div[@class='movie-info section']/p[@itemprop='description']/text()"
 
+    def extraInit(self):
+        self.uncensored = True
+
     def search(self, number):
         self.number = number
-        self.detailurl = f'https://www.caribbeancom.com/moviepages/{number}/index.html'
+        if self.specifiedUrl:
+            self.detailurl = self.specifiedUrl
+        else:
+            self.detailurl = f'https://www.caribbeancom.com/moviepages/{number}/index.html'
         htmlcode = self.getHtml(self.detailurl)
         if htmlcode == 404 or 'class="movie-info section"' not in htmlcode:
             return 404
@@ -87,9 +92,11 @@ class Carib(Parser):
         return o
 
     def getOutline(self, htmltree):
-        from .storyline import getStoryline
-        result = getStoryline(self.number, uncensored=self.uncensored)
-        if len(result):
-            return result
+        if self.morestoryline:
+            from .storyline import getStoryline
+            result = getStoryline(self.number, uncensored=self.uncensored,
+                                  proxies=self.proxies, verify=self.verify)
+            if len(result):
+                return result
         return super().getOutline(htmltree)
 
