@@ -28,14 +28,8 @@ class Getchu():
         return dic
 
 class wwwGetchu(Parser):
-    imagecut = 0
-    allow_number_change = True
-
-    cookies = {'getchu_adalt_flag': 'getchu.com', "adult_check_flag": "1"}
-    GETCHU_WWW_SEARCH_URL = 'http://www.getchu.com/php/search.phtml?genre=anime_dvd&search_keyword=_WORD_&check_key_dtl=1&submit='
-
     expr_title = '//*[@id="soft-title"]/text()'
-    expr_cover = '//head/meta[@property="og:image"]'
+    expr_cover = '//head/meta[@property="og:image"]/@content'
     expr_director = "//td[contains(text(),'ブランド')]/following-sibling::td/a[1]/text()"
     expr_studio = "//td[contains(text(),'ブランド')]/following-sibling::td/a[1]/text()"
     expr_actor = "//td[contains(text(),'ブランド')]/following-sibling::td/a[1]/text()"
@@ -46,6 +40,13 @@ class wwwGetchu(Parser):
     expr_extrafanart = "//div[contains(text(),'サンプル画像')]/following-sibling::div/a/@href"
     expr_series = "//td[contains(text(),'ジャンル：')]/following-sibling::td/text()"
 
+    def extraInit(self):
+        self.imagecut = 0
+        self.allow_number_change = True
+
+        self.cookies = {'getchu_adalt_flag': 'getchu.com', "adult_check_flag": "1"}
+        self.GETCHU_WWW_SEARCH_URL = 'http://www.getchu.com/php/search.phtml?genre=anime_dvd&search_keyword=_WORD_&check_key_dtl=1&submit='
+
     def queryNumberUrl(self, number):
         if 'GETCHU' in number.upper():
             idn = re.findall('\d+',number)[0]
@@ -67,9 +68,6 @@ class wwwGetchu(Parser):
     def getNum(self, htmltree):
         return 'GETCHU-' + re.findall('\d+', self.detailurl.replace("http://www.getchu.com/soft.phtml?id=", ""))[0]
 
-    def getCover(self, htmltree):
-        return self.getTreeElement(htmltree, self.expr_cover).get('content')
-
     def getActors(self, htmltree):
         return super().getDirector(htmltree)
 
@@ -99,16 +97,6 @@ class dlGetchu(wwwGetchu):
     """ 二者基本一致
     headers extrafanart 略有区别
     """
-
-    imagecut = 4
-    allow_number_change = True
-
-    cookies = {"adult_check_flag": "1"}
-    extraheader = {"Referer": "https://dl.getchu.com/"}
-
-    GETCHU_DL_SEARCH_URL = 'https://dl.getchu.com/search/search_list.php?dojin=1&search_category_id=&search_keyword=_WORD_&btnWordSearch=%B8%A1%BA%F7&action=search&set_category_flag=1'
-    GETCHU_DL_URL = 'https://dl.getchu.com/i/item_WORD_'
-
     expr_title = "//div[contains(@style,'color: #333333; padding: 3px 0px 0px 5px;')]/text()"
     expr_director = "//td[contains(text(),'作者')]/following-sibling::td/text()"
     expr_studio = "//td[contains(text(),'サークル')]/following-sibling::td/a/text()"
@@ -120,6 +108,16 @@ class dlGetchu(wwwGetchu):
     expr_extrafanart = "//td[contains(@style,'background-color: #444444;')]/a/@href"
     expr_series = "//td[contains(text(),'サークル')]/following-sibling::td/a/text()"
 
+    def extraInit(self):
+        self.imagecut = 4
+        self.allow_number_change = True
+
+        self.cookies = {"adult_check_flag": "1"}
+        self.extraheader = {"Referer": "https://dl.getchu.com/"}
+
+        self.GETCHU_DL_SEARCH_URL = 'https://dl.getchu.com/search/search_list.php?dojin=1&search_category_id=&search_keyword=_WORD_&btnWordSearch=%B8%A1%BA%F7&action=search&set_category_flag=1'
+        self.GETCHU_DL_URL = 'https://dl.getchu.com/i/item_WORD_'
+
     def queryNumberUrl(self, number):
         if "item" in number or 'GETCHU' in number.upper():
             self.number = re.findall('\d+',number)[0]
